@@ -1,5 +1,6 @@
 #include "mainwindow.h"
 #include "radio.h"
+#include "emittingbutton.h"
 #include "fontdialog.h"
 #include <QSettings>
 #include <QStringList>
@@ -13,6 +14,8 @@
 #include <QMessageBox>
 #include <QApplication>
 #include <QFontDialog>
+#include <QScrollArea>
+#include <QVBoxLayout>
 
 
 
@@ -34,6 +37,8 @@ MainWindow::MainWindow(QWidget *parent)
 
 
 
+
+
     setWindowTitle("QRadio");
 
 
@@ -71,6 +76,11 @@ void MainWindow::createActions()
     connect(restartRadioAction, SIGNAL(triggered()), w, SLOT(restartRadio()));
     changeFontAction = new QAction("Change Font", this);
     connect(changeFontAction, SIGNAL(triggered()), SLOT(changeFontActionTriggered()));
+    forceMonoAction = new QAction("Force Mono", this);
+    forceMonoAction->setCheckable(true);
+    connect(forceMonoAction, SIGNAL(triggered()), SLOT(forceMonoActionTriggered()));
+    stationsListAction = new QAction("Stations List", this);
+    connect (stationsListAction, SIGNAL(triggered()), SLOT(stationsListActionTriggered()));
     aboutAction = new QAction("About", this); connect(aboutAction, SIGNAL(triggered()), SLOT(about()));
     aboutQtAction = new QAction("About Qt", this); connect(aboutQtAction, SIGNAL(triggered()), SLOT(aboutQt()));
 
@@ -102,6 +112,8 @@ void MainWindow::createMenu()
     menu->addAction(manualAction);
     menu->addAction(renameSetsAction);
     //menu->addAction(restartRadioAction);
+    menu->addAction(forceMonoAction);
+    menu->addAction(stationsListAction);
     menu->addAction(changeFontAction);
     menu->addAction(aboutAction);
     menu->addAction(aboutQtAction);
@@ -113,9 +125,9 @@ void MainWindow::addStationTriggered()
 
     switch (currentSet)
     {
-    case (1) :  w->set1List<<(QString::number(freq)); w->stationsList = w->set1List; break;
-    case (2) :  w->set2List<<(QString::number(freq)); w->stationsList = w->set2List; break;
-    case (3) :  w->set3List<<(QString::number(freq)); w->stationsList = w->set3List; break;
+    case (1) :  w->set1List<<(QString::number(freq, 'f', 1)); w->stationsList = w->set1List; break;
+    case (2) :  w->set2List<<(QString::number(freq, 'f', 1)); w->stationsList = w->set2List; break;
+    case (3) :  w->set3List<<(QString::number(freq, 'f', 1)); w->stationsList = w->set3List; break;
     }
 
     w->populateBox();
@@ -207,7 +219,7 @@ void MainWindow::deleteStationActionTriggered()
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                tr("<h2>QRadio 0.1.1</h2>"
+                tr("<h2>QRadio 0.1.2</h2>"
                    "<p>"
                    "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 
@@ -229,4 +241,60 @@ void MainWindow::changeFontActionTriggered()
 void MainWindow::changeFont(QFont font, int n)
 {
     w->changeFont(font, n);
+    }
+
+void MainWindow::forceMonoActionTriggered()
+{
+    if (forceMonoAction->isChecked()) w->forceMono();
+    else w->forceStereo();
+
+}
+
+void MainWindow::stationsListActionTriggered()
+{
+    stationsListCreate();
+    wid->setWindowTitle("QRadio");
+    wid->show();
+}
+
+void MainWindow::stationsListCreate()
+{
+    widget = new QWidget;
+    QScrollArea *scrollArea=new QScrollArea;
+    QVBoxLayout *layout=new QVBoxLayout;
+
+    QStringList tempList=w->getStationsList();
+
+    for (int i=0; i<tempList.size(); i++)
+    {
+        QString tempString=tempList.at(i);
+        EmittingButton *button=new EmittingButton(widget, tempString.toDouble());
+        layout->addWidget(button);
+
+        connect(button, SIGNAL(buttonClicked(int)), w, SLOT(setFreq(int)));
+    }
+
+    layout->addStretch();
+    widget->setLayout(layout);
+    widget->setMinimumWidth(455);
+
+    scrollArea->setWidget(widget);
+    scrollArea->setMinimumWidth(455);
+
+    QLayout *layout1=new QVBoxLayout;
+    layout1->addWidget(scrollArea);
+    //QPushButton *button = new QPushButton("Close");
+
+   // layout1->addWidget(button);
+
+    wid = new QWidget;
+
+    wid->setLayout(layout1);
+    //connect(button, SIGNAL(clicked()), wid, SLOT(close()));
+
+    QFont font(w->getFontType());
+    QFont tempfont(font.toString(), 30);
+    wid->setFont(tempfont);
+    wid->setAttribute(Qt::WA_Maemo5PortraitOrientation);
+
 }
