@@ -34,6 +34,8 @@ private:
     QAction *renameSetsAction;
     QAction *restartRadioAction;
     QAction *changeFontAction;
+    QAction *forceMonoAction;
+    QAction *stationsListAction;
     QAction *aboutAction;
     QAction *aboutQtAction;
 
@@ -46,7 +48,8 @@ private:
     QString set3Name;
 
 
-
+    QWidget *widget;
+    QWidget *wid;
 
 
 public slots:
@@ -61,6 +64,9 @@ public slots:
     void about();
     void aboutQt();
     void changeFont(QFont, int);
+    void forceMonoActionTriggered();
+    void stationsListActionTriggered();
+    void stationsListCreate();
 
 public:
     MainWindow(QWidget *parent = 0);
