@@ -1,5 +1,6 @@
 #include "radio.h"
 #include "mainwindow.h"
+#include "emittingbutton.h"
 #include <QRadioTuner>
 #include <QLCDNumber>
 #include <QLabel>
@@ -138,6 +139,10 @@ void Radio::createUI()
     mainLayout->addLayout(freqLayout);
     mainLayout->addLayout(buttonLayout);
 
+    //EmittingButton *button = new EmittingButton(this, 91.5);
+    //mainLayout->addWidget(button);
+    //connect(button, SIGNAL(buttonClicked(int)), SLOT(setFreq(int)));
+
     setLayout(mainLayout);
 
 
@@ -392,3 +397,20 @@ void Radio::loadCurrentFont()
     currentFont = QFont(currentFontString, currentFontSize);
     changeFont(currentFont, currentFontSize);
 }
+
+void Radio::forceMono()
+{
+    radio->setStereoMode(QRadioTuner::ForceMono);
+    maemoBanner("Radio set to Mono Mode");
+}
+
+void Radio::forceStereo()
+{
+    radio->setStereoMode(QRadioTuner::ForceStereo);
+    maemoBanner("Radio set to Stereo Mode");
+}
+
+QStringList Radio::getStationsList()
+{
+    return stationsList;
+}
